==> one-9.3.2-en-download.zip: one-9.3.2-en/webhelp/one-webhelp/core/navig/contents_one.js <==
//
//	FindinSite-CD-JS-HelpIndex database naturalone
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var naturalone = {
    baseurls: ["../"],
    varname: "naturalone",
    tree: [
        { url: "overview.htm", title: "NaturalONE",
          tree: [
              { url: "relnotes/rn-over.htm", title: "Release Notes",
                tree: [
                    { url: "relnotes/rn-new932.htm", title: "What's New in Version 9.3.2" },
                    { url: "relnotes/rn-new931.htm", title: "What's New in Version 9.3.1" },
                    { url: "relnotes/rn-new921.htm", title: "What's New in Version 9.2.1" },
                    { url: "relnotes/rn-new914.htm", title: "What's New in Version 9.1.4" },
                    { url: "relnotes/rn-new913.htm", title: "What's New in Version 9.1.3" },
                    { url: "relnotes/rn-new912.htm", title: "What's New in Version 9.1.2" },
                    { url: "relnotes/rn-new91.htm", title: "What's New in Version 9.1.1" },
                ]
              },
              { url: "introduction/intro-over.htm", title: "Introduction",
                tree: [
                    { url: "introduction/intro-whatis.htm", title: "What is NaturalONE?" },
                    { url: "introduction/intro-modes.htm", title: "Different Modes for Developing Natural Applications" },
                    { url: "introduction/intro-version.htm", title: "Using a Version Control System" },
                ]
              },
              { url: "install/inst-over.htm", title: "Installation",
                tree: [
                    { url: "install/inst-sysreq.htm", title: "System Requirements" },
                    { url: "install/inst-info.htm", title: "Important Information" },
                    { url: "install/inst-one.htm", title: "Installing NaturalONE" },
                    { url: "install/inst-eclipse.htm", title: "Using Your Own Eclipse" },
                    { url: "install/inst-ndv.htm", title: "Using an Existing Natural Development Server Environment" },
                    { url: "install/inst-exxrpc.htm", title: "Using an EntireX RPC Environment" },
                ]
              },
              { url: "nutshell/nut-over.htm", title: "NaturalONE in a Nutshell",
                tree: [
                    { url: "nutshell/nut-workspace.htm", title: "NaturalONE and the Eclipse Workspace" },
                    { url: "nutshell/nut-project.htm", title: "All About Natural Projects" },
                    { url: "nutshell/nut-team.htm", title: "Working in a Team" },
                    { url: "nutshell/nut-perform-basics.htm", title: "Performance Aspects" },
                    { url: "nutshell/nut-run.htm", title: "The Local Natural Runtime" },
                    { url: "nutshell/nut-lifecycle.htm", title: "The Development Lifecycle: Step by Step" },
                    { url: "nutshell/nut-performance.htm", title: "Performance Analysis of Natural Applications" },
                ]
              },
              { url: "using/use-over.htm", title: "Using NaturalONE",
                tree: [
                    { url: "using/use-start.htm", title: "Starting NaturalONE" },
                    { url: "using/use-perspective.htm", title: "The NaturalONE Perspective" },
                    { url: "using/use-local.htm", title: "Working with Natural Projects in Local Mode",
                      tree: [
                          { url: "using/use-local-view.htm", title: "Viewing the Contents of Your Natural Projects" },
                          { url: "using/use-local-projects.htm", title: "Managing Natural Projects" },
                          { url: "using/use-local-libs.htm", title: "Managing Libraries in a Natural Project" },
                          { url: "using/use-local-objects.htm", title: "Managing Objects in a Natural Project" },
                          { url: "using/use-local-launch.htm", title: "Launching Natural Applications" },
                          { url: "using/use-local-modify.htm", title: "Modifying Objects in the Natural Environment or in the Repository" },
                          { url: "using/use-local-natbuilder.htm", title: "Understanding the Behavior of the Natural Builder" },
                      ]
                    },
                    { url: "using/use-server.htm", title: "Working with Natural Objects in Natural Server Mode",
                      tree: [
                          { url: "using/use-server-remote.htm", title: "Accessing a Remote Development Environment" },
                          { url: "using/use-server-manage.htm", title: "Managing Objects Directly on a Natural Server" },
                          { url: "using/use-server-launch.htm", title: "Launching Natural Applications" },
                          { url: "using/use-server-cmdconsole.htm", title: "Using the Natural Command Console for Mainframes" },
                          { url: "using/use-server-search.htm", title: "Using the Natural Server Search" },
                      ]
                    },
                    { url: "using/nat_server_search.htm", title: "The Natural Server Search" },
                    { url: "using/use-edis.htm", title: "Using the Natural Editors",
                      tree: [
                          { url: "using/use-edis-geninfo.htm", title: "General Information" },
                          { url: "using/use-edis-source.htm", title: "Using the Source Editor" },
                          { url: "using/use-edis-map.htm", title: "Using the Map Editor" },
                          { url: "using/use-edis-ddm.htm", title: "Using the DDM Editor" },
                      ]
                    },
                    { url: "using/use-debug-over.htm", title: "Using the Debugger",
                      tree: [
                          { url: "using/use-debug-nat.htm", title: "Debugging Natural Applications" },
                          { url: "using/use-debug-das.htm", title: "Using a Debug Attach Server" },
                      ]
                    },
                    { url: "using/use-messages.htm", title: "Creating Application-Specific Messages" },
                    { url: "using/use-dbrowser.htm", title: "Using the Data Browser" },
                    { url: "using/use-natdoc.htm", title: "Generating API Documentation with NATdoc" },
                    { url: "using/use-natstyle.htm", title: "Checking Natural Code with NATstyle" },
                    { url: "using/use-profiler.htm", title: "Using the Natural Profiler" },
                    { url: "using/use-coverage.htm", title: "Using the Natural Code Coverage" },
                    { url: "using/use-coverage-jenkins.htm", title: "Using the Natural Coverage Plugin for Jenkins" },
                    { url: "using/use-nattools-utils.htm", title: "Using Natural Tools and Utilities" },
                    { url: "using/use-lastmsg.htm", title: "Using the LastMsg View" },
                    { url: "using/use-xmltoolkit.htm", title: "Using the XML Toolkit" },
                    { url: "using/use-ssl.htm", title: "Use SSL/TLS" },
                    { url: "using/use-deploy.htm", title: "Deploying Applications",
                      tree: [
                          { url: "using/use-deploy-nat.htm", title: "Deploying Natural Applications" },
                          { url: "using/use-deploy-jenkins.htm", title: "Deploying Natural Applications with Jenkins" },
                          { url: "using/use-deploy-java.htm", title: "Deploying Java Applications" },
                          { url: "using/use-deploy-master.htm", title: "Using a Master Deployment" },
                      ]
                    },
                    { url: "using/use-prefer.htm", title: "Setting the Preferences" },
                ]
              },
              { url: "faq/faq.htm", title: "Frequently Asked Questions" },
              { url: "samples/sample-over.htm", title: "Sample Applications",
                tree: [
                    { url: "samples/sample-install.htm", title: "Installing the Sample Applications" },
                    { url: "samples/sample-hello.htm", title: "Hello World Application" },
                    { url: "samples/sample-travel.htm", title: "Travel Approval Application" },
                    { url: "samples/sample-njx.htm", title: "Natural for Ajax Demos" },
                ]
              },
              { url: "glossary/glossary.htm", title: "Glossary" },
          ]
  },
  ]
};

var mainProject = 0;

$.event.trigger({ type: "fishidbloaded", db: naturalone });

==> one-9.3.3-en-download.zip: one-9.3.3-en/webhelp/one-webhelp/core/navig/contents_one.js <==
//
//	FindinSite-CD-JS-HelpIndex database naturalone
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var naturalone = {
    baseurls: ["../"],
    varname: "naturalone",
    tree: [
        { url: "overview.htm", title: "NaturalONE",
          tree: [
              { url: "relnotes/rn-over.htm", title: "Release Notes",
                tree: [
                    { url: "relnotes/rn-about.htm", title: "About these Release Notes" },
                    { url: "relnotes/rn-new933.htm", title: "What's New in Version 9.3.3" },
                    { url: "relnotes/rn-new932.htm", title: "What's New in Version 9.3.2" },
                    { url: "relnotes/rn-new931.htm", title: "What's New in Version 9.3.1" },
                    { url: "relnotes/rn-new921.htm", title: "What's New in Version 9.2.1" },
                    { url: "relnotes/rn-new914.htm", title: "What's New in Version 9.1.4" },
                    { url: "relnotes/rn-new913.htm", title: "What's New in Version 9.1.3" },
                    { url: "relnotes/rn-new912.htm", title: "What's New in Version 9.1.2" },
                    { url: "relnotes/rn-new91.htm", title: "What's New in Version 9.1.1" },
                ]
              },
              { url: "introduction/intro-over.htm", title: "Introduction",
                tree: [
                    { url: "introduction/intro-whatis.htm", title: "What is NaturalONE?" },
                    { url: "introduction/intro-modes.htm", title: "Different Modes for Developing Natural Applications" },
                    { url: "introduction/intro-version.htm", title: "Using a Version Control System" },
                ]
              },
              { url: "install/inst-over.htm", title: "Installation",
                tree: [
                    { url: "install/inst-geninfo.htm", title: "General Information" },
                    { url: "install/inst-sysreq.htm", title: "System Requirements" },
                    { url: "install/inst-info.htm", title: "Important Information" },
                    { url: "install/inst-one.htm", title: "Installing NaturalONE" },
                    { url: "install/inst-eclipse.htm", title: "Using Your Own Eclipse" },
                    { url: "install/inst-ndv.htm", title: "Using an Existing Natural Development Server Environment" },
                    { url: "install/inst-exxrpc.htm", title: "Using an EntireX RPC Environment" },
                ]
              },
              { url: "nutshell/nut-over.htm", title: "NaturalONE in a Nutshell",
                tree: [
                    { url: "nutshell/nut-workspace.htm", title: "NaturalONE and the Eclipse Workspace" },
                    { url: "nutshell/nut-project.htm", title: "All About Natural Projects" },
                    { url: "nutshell/nut-team.htm", title: "Working in a Team" },
                    { url: "nutshell/nut-perform-basics.htm", title: "Performance Aspects" },
                    { url: "nutshell/nut-run.htm", title: "The Local Natural Runtime" },
                    { url: "nutshell/nut-lifecycle.htm", title: "The Development Lifecycle: Step by Step" },
                    { url: "nutshell/nut-performance.htm", title: "Performance Analysis of Natural Applications" },
                ]
              },
              { url: "using/use-over.htm", title: "Using NaturalONE",
                tree: [
                    { url: "using/use-start.htm", title: "Starting NaturalONE" },
                    { url: "using/use-perspective.htm", title: "The NaturalONE Perspective" },
                    { url: "using/use-local.htm", title: "Working with Natural Projects in Local Mode",
                      tree: [
                          { url: "using/use-local-view.htm", title: "Viewing the Contents of Your Natural Projects" },
                          { url: "using/use-local-projects.htm", title: "Managing Natural Projects" },
                          { url: "using/use-local-libs.htm", title: "Managing Libraries in a Natural Project" },
                          { url: "using/use-local-objects.htm", title: "Managing Objects in a Natural Project" },
                          { url: "using/use-local-launch.htm", title: "Launching Natural Applications" },
                          { url: "using/use-local-modify.htm", title: "Modifying Objects in the Natural Environment or in the Repository" },
                          { url: "using/use-local-natbuilder.htm", title: "Understanding the Behavior of the Natural Builder" },
                      ]
                    },
                    { url: "using/use-server.htm", title: "Working with Natural Objects in Natural Server Mode",
                      tree: [
                          { url: "using/use-server-remote.htm", title: "Accessing a Remote Development Environment" },
                          { url: "using/use-server-manage.htm", title: "Managing Objects Directly on a Natural Server" },
                          { url: "using/use-server-launch.htm", title: "Launching Natural Applications in Natural Server Mode" },
                          { url: "using/use-server-cmdconsole.htm", title: "Using the Natural Command Console for Mainframes" },
                          { url: "using/use-server-search.htm", title: "Using the Natural Server Search" },
                          { url: "using/nat_server_search.htm", title: "The Natural Server Search" },
                      ]
                    },
                    { url: "using/use-edis.htm", title: "Using the Natural Editors",
                      tree: [
                          { url: "using/use-edis-geninfo.htm", title: "General Information on the Natural Editors" },
                          { url: "using/use-edis-source.htm", title: "Using the Source Editor" },
                          { url: "using/use-edis-map.htm", title: "Using the Map Editor" },
                          { url: "using/use-edis-ddm.htm", title: "Using the DDM Editor" },
                      ]
                    },
                    { url: "using/use-debug-over.htm", title: "Using the Debugger",
                      tree: [
                          { url: "using/use-debug-nat.htm", title: "Debugging Natural Applications" },
                          { url: "using/use-debug-das.htm", title: "Using a Debug Attach Server" },
                      ]
                    },
                    { url: "using/use-messages.htm", title: "Creating Application-Specific Messages" },
                    { url: "using/use-dbrowser.htm", title: "Using the Data Browser" },
                    { url: "using/use-natdoc.htm", title: "Generating API Documentation with NATdoc" },
                    { url: "using/use-natstyle.htm", title: "Checking Natural Code with NATstyle" },
                    { url: "using/use-profiler.htm", title: "Using the Natural Profiler" },
                    { url: "using/use-coverage.htm", title: "Using the Natural Code Coverage" },
                    { url: "using/use-coverage-jenkins.htm", title: "Using the Natural Coverage Plugin for Jenkins" },
                    { url: "using/use-nattools-utils.htm", title: "Using Natural Tools and Utilities" },
                    { url: "using/use-lastmsg.htm", title: "Using the LastMsg View" },
                    { url: "using/use-xmltoolkit.htm", title: "Using the XML Toolkit" },
                    { url: "using/use-ssl.htm", title: "Use SSL/TLS" },
                    { url: "using/use-deploy.htm", title: "Deploying Applications",
                      tree: [
                          { url: "using/use-deploy-nat.htm", title: "Deploying Natural Applications" },
                          { url: "using/use-deploy-jenkins.htm", title: "Deploying Natural Applications with Jenkins" },
                          { url: "using/use-deploy-java.htm", title: "Deploying Java Applications" },
                          { url: "using/use-deploy-master.htm", title: "Using a Master Deployment" },
                      ]
                    },
                    { url: "using/use-prefer.htm", title: "Setting the Preferences" },
                ]
              },
              { url: "faq/faq.htm", title: "Frequently Asked Questions" },
              { url: "samples/sample-over.htm", title: "Sample Applications",
                tree: [
                    { url: "samples/sample-install.htm", title: "Installing the Sample Applications" },
                    { url: "samples/sample-hello.htm", title: "Hello World Application" },
                    { url: "samples/sample-travel.htm", title: "Travel Approval Application" },
                    { url: "samples/sample-njx.htm", title: "Natural for Ajax Demos" },
                ]
              },
              { url: "glossary/glossary.htm", title: "Glossary" },
          ]
  },
  ]
};

var mainProject = 0;

$.event.trigger({ type: "fishidbloaded", db: naturalone });
